# pyright: reportUnusedImport=false
import struct
from typing import Optional, Self, Sequence
from .. import abcs
from ..core import Request, serialize_bytes_to
_bytes = bytes | bytearray | memoryview
def get_contact_ds(*, hash: int) -> Request[Sequence[int]]:
    _buffer = bytearray(b'\x9df\xdcz')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def get_statuses() -> Request[Sequence[abcs.ContactStatus]]:
    _buffer = bytearray(b'\xeeS\xa3\xc4')
    return Request(b'' + _buffer)
def get_contacts(*, hash: int) -> Request[abcs.contacts.Contacts]:
    _buffer = bytearray(b'\x12\x9e\xd6]')
    _buffer += struct.pack('<q', hash)
    return Request(b'' + _buffer)
def import_contacts(*, contacts: Sequence[abcs.InputContact]) -> Request[abcs.contacts.ImportedContacts]:
    _buffer = bytearray(b'\xe5\x0b\x80,')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(contacts))
    for _t0 in contacts:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def delete_contacts(*, id: Sequence[abcs.InputUser]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x00\x0ej\t')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    for _t0 in id:
      _t0._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def delete_by_phones(*, phones: Sequence[str]) -> Request[bool]:
    _buffer = bytearray(b'\x9e\xfd\x13\x10')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(phones))
    for _t0 in phones:
      serialize_bytes_to(_buffer, _t0.encode('utf-8'))
    return Request(b'' + _buffer)
def block(*, my_stories_from: bool, id: abcs.InputPeer) -> Request[bool]:
    _buffer = bytearray(b'4\x87..')
    flags = (1 if my_stories_from else 0)
    _buffer += struct.pack('<I', flags)
    id._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def unblock(*, my_stories_from: bool, id: abcs.InputPeer) -> Request[bool]:
    _buffer = bytearray(b'(\xd3P\xb5')
    flags = (1 if my_stories_from else 0)
    _buffer += struct.pack('<I', flags)
    id._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_blocked(*, my_stories_from: bool, offset: int, limit: int) -> Request[abcs.contacts.Blocked]:
    _buffer = bytearray(b'\x80\x8f\x86\x9a')
    flags = (1 if my_stories_from else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<ii', offset, limit)
    return Request(b'' + _buffer)
def search(*, q: str, limit: int) -> Request[abcs.contacts.Found]:
    _buffer = bytearray(b'\xd8\x12\xf8\x11')
    serialize_bytes_to(_buffer, q.encode('utf-8'))
    _buffer += struct.pack('<i', limit)
    return Request(b'' + _buffer)
def resolve_username(*, username: str) -> Request[abcs.contacts.ResolvedPeer]:
    _buffer = bytearray(b'\xa3\xcb<\xf9')
    serialize_bytes_to(_buffer, username.encode('utf-8'))
    return Request(b'' + _buffer)
def get_top_peers(*, correspondents: bool, bots_pm: bool, bots_inline: bool, phone_calls: bool, forward_users: bool, forward_chats: bool, groups: bool, channels: bool, offset: int, limit: int, hash: int) -> Request[abcs.contacts.TopPeers]:
    _buffer = bytearray(b'\xb6x4\x97')
    flags = (1 if correspondents else 0) | (2 if bots_pm else 0) | (4 if bots_inline else 0) | (8 if phone_calls else 0) | (16 if forward_users else 0) | (32 if forward_chats else 0) | (1024 if groups else 0) | (32768 if channels else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<iiq', offset, limit, hash)
    return Request(b'' + _buffer)
def reset_top_peer_rating(*, category: abcs.TopPeerCategory, peer: abcs.InputPeer) -> Request[bool]:
    _buffer = bytearray(b'\xacs\xe3\x1a')
    category._write_boxed_to(_buffer)
    peer._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def reset_saved() -> Request[bool]:
    _buffer = bytearray(b'\xf17\x95\x87')
    return Request(b'' + _buffer)
def get_saved() -> Request[Sequence[abcs.SavedContact]]:
    _buffer = bytearray(b'\x9f\xe3\xf1\x82')
    return Request(b'' + _buffer)
def toggle_top_peers(*, enabled: bool) -> Request[bool]:
    _buffer = bytearray(b'\xda\xbd\x14\x85')
    _buffer += struct.pack('<I', enabled)
    return Request(b'' + _buffer)
def add_contact(*, add_phone_privacy_exception: bool, id: abcs.InputUser, first_name: str, last_name: str, phone: str) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\xd0c\xf4\xe8')
    flags = (1 if add_phone_privacy_exception else 0)
    _buffer += struct.pack('<I', flags)
    id._write_boxed_to(_buffer)
    serialize_bytes_to(_buffer, first_name.encode('utf-8'))
    serialize_bytes_to(_buffer, last_name.encode('utf-8'))
    serialize_bytes_to(_buffer, phone.encode('utf-8'))
    return Request(b'' + _buffer)
def accept_contact(*, id: abcs.InputUser) -> Request[abcs.Updates]:
    _buffer = bytearray(b'\x0f\xa21\xf8')
    id._write_boxed_to(_buffer)
    return Request(b'' + _buffer)
def get_located(*, background: bool, geo_point: abcs.InputGeoPoint, self_expires: Optional[int]) -> Request[abcs.Updates]:
    _buffer = bytearray(b'D\xbcH\xd3')
    flags = (2 if background else 0) | (0 if self_expires is None else 1)
    _buffer += struct.pack('<I', flags)
    geo_point._write_boxed_to(_buffer)
    if self_expires is not None:
      _buffer += struct.pack(f'<i', self_expires)
    return Request(b'' + _buffer)
def block_from_replies(*, delete_message: bool, delete_history: bool, report_spam: bool, msg_id: int) -> Request[abcs.Updates]:
    _buffer = bytearray(b',\x96\xa8)')
    flags = (1 if delete_message else 0) | (2 if delete_history else 0) | (4 if report_spam else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<i', msg_id)
    return Request(b'' + _buffer)
def resolve_phone(*, phone: str) -> Request[abcs.contacts.ResolvedPeer]:
    _buffer = bytearray(b'DC\xf9\x8a')
    serialize_bytes_to(_buffer, phone.encode('utf-8'))
    return Request(b'' + _buffer)
def export_contact_token() -> Request[abcs.ExportedContactToken]:
    _buffer = bytearray(b"'@e\xf8")
    return Request(b'' + _buffer)
def import_contact_token(*, token: str) -> Request[abcs.User]:
    _buffer = bytearray(b'\x88W\x00\x13')
    serialize_bytes_to(_buffer, token.encode('utf-8'))
    return Request(b'' + _buffer)
def edit_close_friends(*, id: Sequence[int]) -> Request[bool]:
    _buffer = bytearray(b'\xf0\x05g\xba')
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    _buffer += struct.pack(f'<{len(id)}q', *id)
    return Request(b'' + _buffer)
def set_blocked(*, my_stories_from: bool, id: Sequence[abcs.InputPeer], limit: int) -> Request[bool]:
    _buffer = bytearray(b'v\\\xc6\x94')
    flags = (1 if my_stories_from else 0)
    _buffer += struct.pack('<I', flags)
    _buffer += struct.pack('<ii', 0x1cb5c415, len(id))
    for _t0 in id:
      _t0._write_boxed_to(_buffer)
    _buffer += struct.pack('<i', limit)
    return Request(b'' + _buffer)
